import React, { Fragment } from 'react'
import styles from './Download.less'
import { Flex, Icon, Toast, Result } from 'antd-mobile'
import { getAppLatest } from '@/services/api'
import UserAgent from '@/utils/UserAgent'
import { _appDownloadUrl, isIos, getChannelId } from '../../utils/base'
import Wrap from '@/components/Wrap/Wrap'
import iosImg from '../../assets/apple.png';
import androidImg from '../../assets/android.png';
import leftImg from '../../assets/download_left.png';
import rightImg from '../../assets/download_right.png';

class Download extends React.Component {
  constructor(props) {
    super(props)
    this.state = {
      showMask: false,
      loading: false,
      versionRemarks: '',
      info: {},
      channelId: getChannelId(),
    }
    document.title = '下载APP'
  }

  componentDidMount() {
    if (!this.state.channelId) {
      return
    }
    this.getAppLatest()
  }

  componentWillUnmount() {
    if (this.timer) {
      clearTimeout(this.timer)
    }
  }

  //获取最新版本应用
  async getAppLatest() {
    
    try {
      this.setState({ loading: true })
      const res = await getAppLatest({ clientType: UserAgent.iOS() ? 2 : 3, appType: 11 })
      if (res.success && res.data) {
        const { versionDownloadUrl, versionRemarks } = res.data
        const info = res.data
        if (versionDownloadUrl) {
          this.setState({ loading: false, versionDownloadUrl, versionRemarks, info })
        } else {
          Toast.info('版本正在准备中', 1)
          this.setState({ loading: false, noVersion: true })
        }
      } else if (!res.data) {
        this.setState({ noVersion: true, loading: false })
      } else {
        if (!res.data && !res.msg) {
          res.msg = '获取下载版本失败'
        }
        Toast.info(res.msg, 1)
        this.setState({ loading: false, err: true, errMsg: res.msg })
      }
    } catch (error) {
      this.timer = setTimeout(() => {
        this.setState({ loading: false, noVersion: true })
      }, 600);
    }
  }

  onDownload = () => {
    if (this.state.showTrust) {
      //下载证书
      window.location.href = 'https://starbuds.paqukeji.com/embedded.mobileprovision'
    } else {
      // 判断是否在微信中
      if (UserAgent.wechat() || UserAgent.QQ()) {
        // 微信中需要右上角浏览器打开
        this.setState({ showMask: true })
      } else {
        if (UserAgent.iOS()) {
          //统计下载
          const script = document.createElement('script')
          script.src = _appDownloadUrl
          script.type = 'text/javascript'
          document.body.appendChild(script)

          this.timer = setTimeout(() => {
            alert('您可以切换到桌面查看安装进度')
            this.setState({ showTrust: true })
          }, 2000)
        } else {
          window.location.href = _appDownloadUrl
        }
      }
    }
  }
  render() {
    const { showMask, loading, err, errMsg, noVersion, showTrust, info, channelId } = this.state;
    return (
      <Wrap err={err} errMsg={errMsg} loading={loading} empty={!channelId || noVersion}>
        <div className={styles.download}>
          <img className={styles.logo} src={info.appIcon || require('@/assets/logo.png')} />
          {info.appName && (
            <div className={styles.appName_less}>
              <img className={styles.appName_icon} src={isIos() ? iosImg : androidImg} />
              {info.appName}
            </div>
          )}
          <Flex align="center" justify="center" className={noVersion ? 'hidden' : styles.button}>
            {loading ? <Icon type="loading" /> : (
              <Fragment>
                <img className={styles.icon} src={require('@/assets/icon_download.png')} />
                <div className={styles.text} onClick={this.onDownload.bind(this)}>
                  <span>{showTrust ? '下载证书' : '立即下载'}</span>
                </div>
              </Fragment>
            )}
          </Flex>
          {noVersion && <div className="color-999 font-28">版本正在准备中</div>}
          {/* 版本说明 */}
          <div className={styles.notice}>
            <div className="color-999 font-24">{!showTrust ? `版本号：${info.versionCode} 包大小：${info.versionFileSize}` : '安装完成后记得回来下载证书哦'}</div>
            <Flex justify="center" style={{ marginTop: '0.3rem' }}>
              <div
                className={`color-999 font-24 ${styles.remark}`}
                dangerouslySetInnerHTML={{ __html: this.state.versionRemarks.replace(/\n/g, "<br />") }}
              />
            </Flex>
          </div>
          <div className={styles.mask} style={{ display: showMask ? '' : 'none' }}>
            <img src={require('../../assets/wx_tips_android.png')} />
          </div>
          {/* <div className={styles.footer}>
            <div className="color-999 font-24">浙江帕趣网络科技有限公司&nbsp;&copy;&nbsp;2019<br />浙ICP备19043479号</div>
          </div> */}
          <img className={styles.download_left} src={leftImg} />
          <img className={styles.download_right} src={rightImg} />
        </div>
      </Wrap>

    )
  }
}

export default Download
